==> jc-1.4.0.tar.gz: javax/print/attribute/AttributeSetUtilities__24SynchronizedPrintJobAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$SynchronizedPrintJobAttributeSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a977668ae8c65227 javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet
// @dep_class bf9e0d6aac96e0b4 javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24SynchronizedAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_PrintJobAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$method$_init$e5a7e9c8f2357d04(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/AttributeSetUtilities__24SynchronizedPrintJobAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$SynchronizedPrintJobAttributeSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a977668ae8c65227 javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet
// @dep_class bf9e0d6aac96e0b4 javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24SynchronizedAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_PrintJobAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$method$_init$e5a7e9c8f2357d04(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintJobAttributeSet_H_ */
